@@ -20,11 +20,7 @@
 
 use arrayvec::ArrayString;
 use gtk::glib::{g_critical, g_debug};
-use std::num::NonZeroU32;
-use std::sync::atomic::{AtomicBool, AtomicU32, Ordering};
-use std::time::Duration;
-use std::{cell::RefCell, collections::HashMap, sync::Arc};
-
+use magpie_types::about::{about_response, About};
 use magpie_types::apps::apps_response;
 use magpie_types::apps::apps_response::AppList;
 pub use magpie_types::apps::App;
@@ -56,6 +52,10 @@ use magpie_types::prost::Message;
 use magpie_types::services::services_response;
 use magpie_types::services::services_response::ServiceList;
 pub use magpie_types::services::Service;
+use std::num::NonZeroU32;
+use std::sync::atomic::{AtomicBool, AtomicU32, Ordering};
+use std::time::Duration;
+use std::{cell::RefCell, collections::HashMap, sync::Arc};
 
 use crate::magpie_client::flatpak_app_path;
 use crate::{flatpak_data_dir, is_flatpak, show_error_dialog_and_exit};
@@ -65,6 +65,7 @@ mod nng {
 }
 
 type ResponseBody = response::Body;
+type AboutResponse = about_response::Response;
 type AppsResponse = apps_response::Response;
 type CpuResponse = cpu_response::Response;
 type DisksResponse = disks_response::Response;
@@ -615,6 +616,21 @@ impl Client {
             .store(v, Ordering::Relaxed);
     }
 
+    pub fn about(&self) -> About {
+        let mut socket = self.socket.borrow_mut();
+
+        let response = make_request(ipc::req_get_about(), &mut socket, self.socket_addr.as_ref())
+            .and_then(|response| response.body);
+
+        parse_response!(
+            response,
+            ResponseBody::About,
+            AboutResponse::AboutInfo,
+            AboutResponse::Error,
+            |about: About| about
+        )
+    }
+
     pub fn cpu(&self) -> Cpu {
         let mut socket = self.socket.borrow_mut();
 
@@ -870,11 +886,11 @@ impl Client {
         )
     }
 
-    pub fn services(&self) -> HashMap<String, Service> {
+    pub fn user_services(&self) -> HashMap<u64, Service> {
         let mut socket = self.socket.borrow_mut();
 
         let response = make_request(
-            ipc::req_get_services(),
+            ipc::req_get_user_services(),
             &mut socket,
             self.socket_addr.as_ref(),
         )
@@ -889,13 +905,38 @@ impl Client {
                 service_list
                     .services
                     .drain(..)
-                    .map(|service| (service.id.clone(), service))
+                    .map(|service| (service.id, service))
                     .collect()
             }
         )
     }
 
-    pub fn service_logs(&self, service_id: String, pid: Option<NonZeroU32>) -> String {
+    pub fn system_services(&self) -> HashMap<u64, Service> {
+        let mut socket = self.socket.borrow_mut();
+
+        let response = make_request(
+            ipc::req_get_system_services(),
+            &mut socket,
+            self.socket_addr.as_ref(),
+        )
+        .and_then(|response| response.body);
+
+        parse_response!(
+            response,
+            ResponseBody::Services,
+            ServicesResponse::Services,
+            ServicesResponse::Error,
+            |mut service_list: ServiceList| {
+                service_list
+                    .services
+                    .drain(..)
+                    .map(|service| (service.id, service))
+                    .collect()
+            }
+        )
+    }
+
+    pub fn service_logs(&self, service_id: u64, pid: Option<NonZeroU32>) -> String {
         let mut socket = self.socket.borrow_mut();
 
         let response = make_request(
@@ -952,7 +993,121 @@ impl Client {
         )
     }
 
-    pub fn start_service(&self, service_id: String) {
+    pub fn interrupt_processes(&self, pids: Vec<u32>) {
+        let mut socket = self.socket.borrow_mut();
+
+        let response = make_request(
+            ipc::req_interrupt_processes(pids),
+            &mut socket,
+            self.socket_addr.as_ref(),
+        )
+        .and_then(|response| response.body);
+
+        parse_response!(
+            response,
+            ResponseBody::Processes,
+            ProcessesResponse::TermKill,
+            ProcessesResponse::Error,
+            |_| {}
+        )
+    }
+
+    pub fn signal_user_one_processes(&self, pids: Vec<u32>) {
+        let mut socket = self.socket.borrow_mut();
+
+        let response = make_request(
+            ipc::req_signal_user_one_processes(pids),
+            &mut socket,
+            self.socket_addr.as_ref(),
+        )
+        .and_then(|response| response.body);
+
+        parse_response!(
+            response,
+            ResponseBody::Processes,
+            ProcessesResponse::TermKill,
+            ProcessesResponse::Error,
+            |_| {}
+        )
+    }
+
+    pub fn signal_user_two_processes(&self, pids: Vec<u32>) {
+        let mut socket = self.socket.borrow_mut();
+
+        let response = make_request(
+            ipc::req_signal_user_two_processes(pids),
+            &mut socket,
+            self.socket_addr.as_ref(),
+        )
+        .and_then(|response| response.body);
+
+        parse_response!(
+            response,
+            ResponseBody::Processes,
+            ProcessesResponse::TermKill,
+            ProcessesResponse::Error,
+            |_| {}
+        )
+    }
+
+    pub fn hangup_processes(&self, pids: Vec<u32>) {
+        let mut socket = self.socket.borrow_mut();
+
+        let response = make_request(
+            ipc::req_hangup_processes(pids),
+            &mut socket,
+            self.socket_addr.as_ref(),
+        )
+        .and_then(|response| response.body);
+
+        parse_response!(
+            response,
+            ResponseBody::Processes,
+            ProcessesResponse::TermKill,
+            ProcessesResponse::Error,
+            |_| {}
+        )
+    }
+
+    pub fn continue_processes(&self, pids: Vec<u32>) {
+        let mut socket = self.socket.borrow_mut();
+
+        let response = make_request(
+            ipc::req_continue_processes(pids),
+            &mut socket,
+            self.socket_addr.as_ref(),
+        )
+        .and_then(|response| response.body);
+
+        parse_response!(
+            response,
+            ResponseBody::Processes,
+            ProcessesResponse::TermKill,
+            ProcessesResponse::Error,
+            |_| {}
+        )
+    }
+
+    pub fn suspend_processes(&self, pids: Vec<u32>) {
+        let mut socket = self.socket.borrow_mut();
+
+        let response = make_request(
+            ipc::req_suspend_processes(pids),
+            &mut socket,
+            self.socket_addr.as_ref(),
+        )
+        .and_then(|response| response.body);
+
+        parse_response!(
+            response,
+            ResponseBody::Processes,
+            ProcessesResponse::TermKill,
+            ProcessesResponse::Error,
+            |_| {}
+        )
+    }
+
+    pub fn start_service(&self, service_id: u64) {
         let mut socket = self.socket.borrow_mut();
 
         let response = make_request(
@@ -971,7 +1126,7 @@ impl Client {
         )
     }
 
-    pub fn stop_service(&self, service_id: String) {
+    pub fn stop_service(&self, service_id: u64) {
         let mut socket = self.socket.borrow_mut();
 
         let response = make_request(
@@ -990,7 +1145,7 @@ impl Client {
         )
     }
 
-    pub fn restart_service(&self, service_id: String) {
+    pub fn restart_service(&self, service_id: u64) {
         let mut socket = self.socket.borrow_mut();
 
         let response = make_request(
@@ -1009,7 +1164,7 @@ impl Client {
         )
     }
 
-    pub fn enable_service(&self, service_id: String) {
+    pub fn enable_service(&self, service_id: u64) {
         let mut socket = self.socket.borrow_mut();
 
         let response = make_request(
@@ -1028,7 +1183,7 @@ impl Client {
         )
     }
 
-    pub fn disable_service(&self, service_id: String) {
+    pub fn disable_service(&self, service_id: u64) {
         let mut socket = self.socket.borrow_mut();
 
         let response = make_request(
