@@ -56,9 +56,11 @@ mod imp {
 
         #[property(get = Self::infobar_content, type = Option < gtk::Widget >)]
         pub infobar_content: OnceCell<gtk::Box>,
+        pub power_row: OnceCell<gtk::Box>,
 
         pub utilization: OnceCell<gtk::Label>,
         pub speed: OnceCell<gtk::Label>,
+        pub power_draw: OnceCell<gtk::Label>,
         pub processes: OnceCell<gtk::Label>,
         pub threads: OnceCell<gtk::Label>,
         pub handles: OnceCell<gtk::Label>,
@@ -92,8 +94,11 @@ mod imp {
                 graph_widgets: Cell::new(Vec::new()),
 
                 infobar_content: Default::default(),
+                power_row: Default::default(),
+
                 utilization: Default::default(),
                 speed: Default::default(),
+                power_draw: Default::default(),
                 processes: Default::default(),
                 threads: Default::default(),
                 handles: Default::default(),
@@ -360,10 +365,8 @@ mod imp {
                 }
             }
 
-            let settings = settings!();
-
             let l1_cache_size = if let Some(size) = static_cpu_info.l1_combined_cache_bytes {
-                crate::to_human_readable_nice(size as f32, &DataType::MemoryBytes, &settings)
+                crate::to_human_readable_nice(size as f32, &DataType::MemoryBytes)
             } else {
                 i18n("N/A")
             };
@@ -372,7 +375,7 @@ mod imp {
             }
 
             let l2_cache_size = if let Some(size) = static_cpu_info.l2_cache_bytes {
-                crate::to_human_readable_nice(size as f32, &DataType::MemoryBytes, &settings)
+                crate::to_human_readable_nice(size as f32, &DataType::MemoryBytes)
             } else {
                 i18n("N/A")
             };
@@ -381,7 +384,7 @@ mod imp {
             }
 
             let l3_cache_size = if let Some(size) = static_cpu_info.l3_cache_bytes {
-                crate::to_human_readable_nice(size as f32, &DataType::MemoryBytes, &settings)
+                crate::to_human_readable_nice(size as f32, &DataType::MemoryBytes)
             } else {
                 i18n("N/A")
             };
@@ -390,7 +393,7 @@ mod imp {
             }
 
             let _ = if let Some(size) = static_cpu_info.l4_cache_bytes {
-                crate::to_human_readable_nice(size as f32, &DataType::MemoryBytes, &settings)
+                crate::to_human_readable_nice(size as f32, &DataType::MemoryBytes)
             } else {
                 i18n("N/A")
             };
@@ -438,6 +441,18 @@ mod imp {
                 ));
             }
 
+            if let Some(power_draw) = this.power_draw.get() {
+                if let Some(power_draw_num) = dynamic_cpu_info.power_draw_w {
+                    power_draw.set_text(&crate::to_human_readable_nice(
+                        power_draw_num,
+                        &DataType::Watts,
+                    ))
+                } else {
+                    if let Some(power_row) = this.power_row.get() {
+                        power_row.set_visible(false)
+                    }
+                }
+            }
             if let Some(processes) = this.processes.get() {
                 processes.set_text(&format!("{}", dynamic_cpu_info.total_process_count));
             }
@@ -829,6 +844,16 @@ mod imp {
                     .object::<gtk::Label>("speed")
                     .expect("Could not find `speed` object in details pane"),
             );
+            let _ = self.power_draw.set(
+                sidebar_content_builder
+                    .object::<gtk::Label>("power_draw")
+                    .expect("Could not find `power_draw` object in details pane"),
+            );
+            let _ = self.power_row.set(
+                sidebar_content_builder
+                    .object::<gtk::Box>("power_row")
+                    .expect("Could not find `power_row` object in details pane"),
+            );
             let _ = self.processes.set(
                 sidebar_content_builder
                     .object::<gtk::Label>("processes")
@@ -932,7 +957,7 @@ mod imp {
 glib::wrapper! {
     pub struct PerformancePageCpu(ObjectSubclass<imp::PerformancePageCpu>)
         @extends gtk::Box, gtk::Widget,
-        @implements gio::ActionGroup, gio::ActionMap;
+        @implements gio::ActionGroup, gio::ActionMap, gtk::ConstraintTarget, gtk::Accessible, gtk::Buildable;
 }
 
 impl PageExt for PerformancePageCpu {
