@@ -348,7 +348,6 @@ mod imp {
             let total_mem = crate::to_human_readable_nice(
                 readings.mem_info.mem_total as _,
                 &DataType::MemoryBytes,
-                settings,
             );
             this.total_ram.set_text(&total_mem);
             this.max_graph_ram.set_text(&total_mem);
@@ -356,7 +355,6 @@ mod imp {
             let total_swap = crate::to_human_readable_nice(
                 readings.mem_info.swap_total as _,
                 &DataType::MemoryBytes,
-                settings,
             );
             this.total_swap.set_text(&total_swap);
 
@@ -411,8 +409,6 @@ mod imp {
             let this = this.imp();
             let mem_info = &readings.mem_info;
 
-            let settings = &settings!();
-
             // https://gitlab.com/procps-ng/procps/-/blob/master/library/meminfo.c?ref_type=heads#L736
             let mem_avail = if mem_info.mem_available > mem_info.mem_total {
                 mem_info.mem_free
@@ -428,14 +424,12 @@ mod imp {
             let total_mem = crate::to_human_readable_nice(
                 readings.mem_info.mem_total as _,
                 &DataType::MemoryBytes,
-                settings,
             );
             this.total_ram.set_text(&total_mem);
 
             let max_ram = crate::to_human_readable_nice(
                 this.usage_graph.value_range_max(),
                 &DataType::MemoryBytes,
-                settings,
             );
             this.max_graph_ram.set_text(&max_ram);
 
@@ -444,34 +438,25 @@ mod imp {
 
             this.mem_composition.update_memory_information(mem_info);
 
-            let used = crate::to_human_readable_nice(used as _, &DataType::MemoryBytes, settings);
+            let used = crate::to_human_readable_nice(used as _, &DataType::MemoryBytes);
             if let Some(iu) = this.in_use.get() {
                 iu.set_text(&used);
             }
 
-            let available = crate::to_human_readable_nice(
-                mem_info.mem_available as _,
-                &DataType::MemoryBytes,
-                settings,
-            );
+            let available =
+                crate::to_human_readable_nice(mem_info.mem_available as _, &DataType::MemoryBytes);
             if let Some(av) = this.available.get() {
                 av.set_text(&available);
             }
 
-            let committed = crate::to_human_readable_nice(
-                mem_info.committed as _,
-                &DataType::MemoryBytes,
-                settings,
-            );
+            let committed =
+                crate::to_human_readable_nice(mem_info.committed as _, &DataType::MemoryBytes);
             if let Some(cm) = this.committed.get() {
                 cm.set_text(&committed);
             }
 
-            let cached = crate::to_human_readable_nice(
-                mem_info.cached as _,
-                &DataType::MemoryBytes,
-                settings,
-            );
+            let cached =
+                crate::to_human_readable_nice(mem_info.cached as _, &DataType::MemoryBytes);
             if let Some(ch) = this.cached.get() {
                 ch.set_text(&cached);
             }
@@ -488,11 +473,8 @@ mod imp {
                     su.set_visible(false);
                 }
             } else {
-                let swap_available = crate::to_human_readable_nice(
-                    mem_info.swap_total as _,
-                    &DataType::MemoryBytes,
-                    settings,
-                );
+                let swap_available =
+                    crate::to_human_readable_nice(mem_info.swap_total as _, &DataType::MemoryBytes);
                 if let Some(sa) = this.swap_available.get() {
                     sa.set_visible(true);
                     sa.set_text(&swap_available);
@@ -501,7 +483,6 @@ mod imp {
                 let swap_used = crate::to_human_readable_nice(
                     mem_info.swap_total.saturating_sub(mem_info.swap_free) as _,
                     &DataType::MemoryBytes,
-                    settings,
                 );
                 if let Some(su) = this.swap_used.get() {
                     su.set_visible(true);
@@ -509,18 +490,10 @@ mod imp {
                 }
             }
 
-            let free = crate::to_human_readable_nice(
-                mem_info.mem_free as _,
-                &DataType::MemoryBytes,
-                settings,
-            );
-            let dirty = crate::to_human_readable_nice(
-                mem_info.dirty as _,
-                &DataType::MemoryBytes,
-                settings,
-            );
-            let standby =
-                crate::to_human_readable_nice(standby as _, &DataType::MemoryBytes, settings);
+            let free =
+                crate::to_human_readable_nice(mem_info.mem_free as _, &DataType::MemoryBytes);
+            let dirty = crate::to_human_readable_nice(mem_info.dirty as _, &DataType::MemoryBytes);
+            let standby = crate::to_human_readable_nice(standby as _, &DataType::MemoryBytes);
 
             if let Some(l) = this.tt_label_in_use.get() {
                 l.set_text(&used)
@@ -541,7 +514,6 @@ mod imp {
             let total_swap = crate::to_human_readable_nice(
                 readings.mem_info.swap_total as _,
                 &DataType::MemoryBytes,
-                settings,
             );
             this.total_swap.set_text(&total_swap);
 
@@ -830,7 +802,7 @@ mod imp {
 glib::wrapper! {
     pub struct PerformancePageMemory(ObjectSubclass<imp::PerformancePageMemory>)
         @extends gtk::Box, gtk::Widget,
-        @implements gio::ActionGroup, gio::ActionMap;
+        @implements gio::ActionGroup, gio::ActionMap, gtk::ConstraintTarget, gtk::Accessible, gtk::Buildable;
 }
 
 impl PageExt for PerformancePageMemory {
