@@ -27,7 +27,7 @@ use gtk::{gio, glib, prelude::*};
 use magpie_types::network::{Connection, ConnectionKind};
 
 use super::{widgets::GraphWidget, PageExt};
-use crate::{application::INTERVAL_STEP, i18n::*, settings, to_short_human_readable_time};
+use crate::{application::INTERVAL_STEP, i18n::*, to_short_human_readable_time};
 
 mod imp {
     use super::*;
@@ -348,8 +348,6 @@ mod imp {
         ) -> bool {
             let this = this.imp();
 
-            let settings = &settings!();
-
             this.usage_graph
                 .add_data_point(0, connection.tx_rate_bytes_ps);
             this.usage_graph
@@ -397,7 +395,6 @@ mod imp {
                             crate::to_human_readable_nice(
                                 *freq as f32 * 1_000_000.,
                                 &DataType::Hertz,
-                                settings,
                             )
                         },
                     ));
@@ -409,7 +406,6 @@ mod imp {
                     let max_label = crate::to_human_readable_nice(
                         max_speed as f32,
                         &DataType::NetworkBytesPerSecond,
-                        settings,
                     );
 
                     max_bitrate.set_text(max_label.as_str());
@@ -423,24 +419,17 @@ mod imp {
             let max_y = crate::to_human_readable_nice(
                 this.usage_graph.value_range_max(),
                 &DataType::NetworkBytesPerSecond,
-                settings,
             );
             this.max_y.set_text(&max_y);
 
-            let speed_send_info = crate::to_human_readable_nice(
-                send_speed,
-                &DataType::NetworkBytesPerSecond,
-                settings,
-            );
+            let speed_send_info =
+                crate::to_human_readable_nice(send_speed, &DataType::NetworkBytesPerSecond);
             if let Some(speed_send) = this.speed_send.get() {
                 speed_send.set_text(&speed_send_info);
             }
 
-            let speed_recv_info = crate::to_human_readable_nice(
-                rec_speed,
-                &DataType::NetworkBytesPerSecond,
-                settings,
-            );
+            let speed_recv_info =
+                crate::to_human_readable_nice(rec_speed, &DataType::NetworkBytesPerSecond);
             if let Some(speed_recv) = this.speed_recv.get() {
                 speed_recv.set_text(&speed_recv_info);
             }
@@ -448,7 +437,6 @@ mod imp {
             let sent = crate::to_human_readable_nice(
                 connection.tx_total_bytes as f32,
                 &DataType::NetworkBytes,
-                settings,
             );
             if let Some(total_sent) = this.total_sent.get() {
                 total_sent.set_text(&sent);
@@ -456,7 +444,6 @@ mod imp {
             let received = crate::to_human_readable_nice(
                 connection.rx_total_bytes as f32,
                 &DataType::NetworkBytes,
-                settings,
             );
             if let Some(total_recv) = this.total_recv.get() {
                 total_recv.set_text(&received);
@@ -698,7 +685,7 @@ mod imp {
 glib::wrapper! {
     pub struct PerformancePageNetwork(ObjectSubclass<imp::PerformancePageNetwork>)
         @extends gtk::Box, gtk::Widget,
-        @implements gio::ActionGroup, gio::ActionMap;
+        @implements gio::ActionGroup, gio::ActionMap, gtk::ConstraintTarget, gtk::Accessible, gtk::Buildable;
 }
 
 impl PageExt for PerformancePageNetwork {
