@@ -133,17 +133,18 @@ async fn run_nethogs(sender: Sender<NethogsRecord>) {
     let out_rx = cmd.out_rx();
     async_runtime().spawn(cmd.run());
 
-    let nethogs_regex =
-        match RegexBuilder::new(r"^\s*(\d+|\?) (.{8}) (.*?)\s+(.{7})([ \d.]{12})([ \d.]{12})[Bb]")
-            .multi_line(true)
-            .build()
-        {
-            Ok(p) => p,
-            Err(e) => {
-                log::warn!("Failed to build nethogs regex {}", e);
-                return;
-            }
-        };
+    let nethogs_regex = match RegexBuilder::new(
+        r"^\s*(\d+|\?) (.{8}) (.*?)\s+(.{0,16})([ \d.]{12})([ \d.]{12})[Bb]",
+    )
+    .multi_line(true)
+    .build()
+    {
+        Ok(p) => p,
+        Err(e) => {
+            log::warn!("Failed to build nethogs regex {}", e);
+            return;
+        }
+    };
 
     // TODO report the difference between no nethogs and no perms
     // let mut is_alive = false;
